pub enum IgnoredVerdict {
Accounted {
ignored: u64,
},
Uncovered {
ignored: u64,
},
Mismatch {
ignored: u64,
covered: u64,
},
}Expand description
The verdict on one reconcile_ignored command’s ignored tests.
Variants
Accounted
Every ignored test was executed by the declared coverer (or there were none to account for).
Uncovered
Tests were ignored and no command declared itself their coverer. This is the F62 shape exactly.
Mismatch
A coverer ran, but not the same number of tests that were ignored.
Implementations
Sourceimpl IgnoredVerdict
impl IgnoredVerdict